#include "parser.hpp" 

// Гарантируется наличие минимума нужных аргументов для flood и scan
// Гарантируется, что после работы парсера мы получим только валидный тип атаки 

// Добавить:
// 1. Валидацию IP, port



int parse_params(int argc, char** argv, Options& opts) {
    // Короткие опции (с двоеточием для параметров)
    const char* short_options = "a:d:i:p:l:t:b:h";
    
    // Длинные опции
    const struct option long_options[] = {
        {"attack",    required_argument, NULL, 'a'},
        {"domain",    required_argument, NULL, 'd'},
        {"ip",        required_argument, NULL, 'i'},
        {"port",      required_argument, NULL, 'p'},
        {"log",       required_argument, NULL, 'l'},
        {"telegram",  required_argument, NULL, 't'},
        {"token",     required_argument, NULL, 'b'},
        {"help",      no_argument,       NULL, 'h'},
        {NULL,     0,                 NULL,  0}
    };

    int opt;
    while ((opt = getopt_long(argc, argv, short_options, long_options, NULL)) != -1) {
        switch (opt) {
            case 'a':
                opts.attack_type = optarg;
                break;
            case 'd':
                opts.domain = optarg;
                break;
            case 'i':
                opts.ip = optarg;
                break;
            case 'p':
                opts.port = optarg;
                break;
            case 'l':
                opts.log_file = optarg;
                break;
            case 't':
                opts.telegram_id = optarg;
                break;
            case 'b':
                opts.telegram_token = optarg;
                break;
            case 'h':
                std::cout << "Usage: " << argv[0] << " [options]\n"
                          << "Required:\n"
                          << "  -a, --attack TYPE    Type of attack (scan|flood)\n"
                          << "  -d, --domain DOMAIN  Target domain\n"
                          << "  -i, --ip IP          Target IP\n"
                          << "  -p, --port PORT      Port. Required only for flood type!\n"
                          << "Optional:\n"
                          << "  -l, --log FILE       Log file\n"
                          << "  -t, --telegram ID    Telegram ID\n"
                          << "  -b, --token TOKEN    Telegram bot token\n";
                return 1;
            case '?':
                std::cerr << "Unknown option!\n.--help for info\n";
                return 1;
            default:
                return 1;
        }
    }

    // Проверка обязательных параметров
    if (opts.attack_type.empty()) {
        std::cerr << "Error: Missing required parameters!\n--help for more info\n";
        return 1;
    }
    else if (opts.attack_type != "flood" && opts.attack_type != "scan"){
        std::cerr << "Error: Only scan or flood type of attack!\n--help for more info\n";
        return 1;
    }
    else if (opts.attack_type == "flood" && (opts.domain.empty() || opts.ip.empty() || opts.port.empty())) {
        std::cerr << "Error: Missing required parameters!\n--help for more info\n";
        return 1;
    }
    else if (opts.attack_type == "scan" && (opts.domain.empty() || opts.ip.empty())) {
        std::cerr << "Error: Missing required parameters!\n--help for more info\n";
        return 1;
    }

    return 0;
}